Module: Aws::SagemakerJobRuntime

Defined in:
lib/aws-sdk-sagemakerjobruntime/endpoint_parameters.rb,
lib/aws-sdk-sagemakerjobruntime/plugins/endpoints.rb,
lib/aws-sdk-sagemakerjobruntime/endpoint_provider.rb,
lib/aws-sdk-sagemakerjobruntime/client_api.rb,
lib/aws-sdk-sagemakerjobruntime/endpoints.rb,
lib/aws-sdk-sagemakerjobruntime/resource.rb,
lib/aws-sdk-sagemakerjobruntime/errors.rb,
lib/aws-sdk-sagemakerjobruntime/client.rb,
lib/aws-sdk-sagemakerjobruntime/types.rb,
lib/aws-sdk-sagemakerjobruntime.rb

Overview

This module provides support for Sagemaker Job Runtime Service. This module is available in the ‘aws-sdk-sagemakerjobruntime` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

sagemaker_job_runtime = Aws::SagemakerJobRuntime::Client.new
resp = sagemaker_job_runtime.complete_rollout(params)

See Client for more information.

# Errors

Errors returned from Sagemaker Job Runtime Service are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::SagemakerJobRuntime::Errors::ServiceError
  # rescues all Sagemaker Job Runtime Service API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.0.0'