Module: Aws::SagemakerJobRuntime::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/errors.rb
Overview
When SagemakerJobRuntime returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::SagemakerJobRuntime::Errors::ServiceError < Errors::ServiceError
You can rescue all SagemakerJobRuntime errors using ServiceError:
begin
# do stuff
rescue Aws::SagemakerJobRuntime::Errors::ServiceError
# rescues all SagemakerJobRuntime API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, InternalServiceError, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException