Class: Aws::SagemakerJobRuntime::Types::CompleteRolloutRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemakerjobruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50

class CompleteRolloutRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The job ARN.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50

class CompleteRolloutRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The target status for the trajectory. Defaults to READY if not specified. Set to FAILED if the rollout encountered an error and the trajectory should not be used for processing.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50

class CompleteRolloutRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#trajectory_idString

The trajectory ID to mark as complete.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50

class CompleteRolloutRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end