Class: Aws::SagemakerJobRuntime::Types::SampleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SagemakerJobRuntime::Types::SampleRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:body]
Instance Attribute Summary collapse
-
#body ⇒ String
The raw inference request body in OpenAI-compatible JSON format.
-
#job_arn ⇒ String
The job ARN that identifies which model session to route the inference request to.
-
#trajectory_id ⇒ String
The trajectory ID for grouping turns into a single rollout.
Instance Attribute Details
#body ⇒ String
The raw inference request body in OpenAI-compatible JSON format.
118 119 120 121 122 123 124 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 118 class SampleRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |
#job_arn ⇒ String
The job ARN that identifies which model session to route the inference request to.
118 119 120 121 122 123 124 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 118 class SampleRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |
#trajectory_id ⇒ String
The trajectory ID for grouping turns into a single rollout. Each turn (prompt and response) is captured for later use.
118 119 120 121 122 123 124 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 118 class SampleRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |