Class: Aws::SagemakerJobRuntime::Types::SampleWithResponseStreamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SagemakerJobRuntime::Types::SampleWithResponseStreamRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:body]
Instance Attribute Summary collapse
-
#body ⇒ String
The raw inference request body in OpenAI-compatible JSON format.
-
#job_arn ⇒ String
The job ARN that identifies which model session to route the inference request to.
-
#trajectory_id ⇒ String
The trajectory ID for grouping turns into a single rollout.
Instance Attribute Details
#body ⇒ String
The raw inference request body in OpenAI-compatible JSON format.
159 160 161 162 163 164 165 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 159 class SampleWithResponseStreamRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |
#job_arn ⇒ String
The job ARN that identifies which model session to route the inference request to.
159 160 161 162 163 164 165 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 159 class SampleWithResponseStreamRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |
#trajectory_id ⇒ String
The trajectory ID for grouping turns into a single rollout. Each turn is captured for later use.
159 160 161 162 163 164 165 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 159 class SampleWithResponseStreamRequest < Struct.new( :job_arn, :trajectory_id, :body) SENSITIVE = [:body] include Aws::Structure end |