Class: Aws::SagemakerJobRuntime::Types::SampleWithResponseStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SagemakerJobRuntime::Types::SampleWithResponseStreamResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:body]
Instance Attribute Summary collapse
-
#body ⇒ IO
The streaming response body, delivered as a series of PayloadPart events.
-
#content_type ⇒ String
MIME type of the streaming inference result.
Instance Attribute Details
#body ⇒ IO
The streaming response body, delivered as a series of PayloadPart events.
178 179 180 181 182 183 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 178 class SampleWithResponseStreamResponse < Struct.new( :content_type, :body) SENSITIVE = [:body] include Aws::Structure end |
#content_type ⇒ String
MIME type of the streaming inference result.
178 179 180 181 182 183 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 178 class SampleWithResponseStreamResponse < Struct.new( :content_type, :body) SENSITIVE = [:body] include Aws::Structure end |