Class: Aws::SagemakerJobRuntime::Types::UpdateRewardRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemakerjobruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234

class UpdateRewardRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :rewards,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The job ARN.

Returns:

  • (String)


234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234

class UpdateRewardRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :rewards,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#rewardsArray<Float>

The list of reward values to assign to this trajectory. Provide one reward value per turn in the trajectory.

Returns:

  • (Array<Float>)


234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234

class UpdateRewardRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :rewards,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#trajectory_idString

The trajectory ID to update with reward values.

Returns:

  • (String)


234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234

class UpdateRewardRequest < Struct.new(
  :job_arn,
  :trajectory_id,
  :rewards,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end