Class: Aws::SagemakerJobRuntime::Types::CompleteRolloutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SagemakerJobRuntime::Types::CompleteRolloutRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#job_arn ⇒ String
The job ARN.
-
#status ⇒ String
The target status for the trajectory.
-
#trajectory_id ⇒ String
The trajectory ID to mark as complete.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
50 51 52 53 54 55 56 57 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50 class CompleteRolloutRequest < Struct.new( :job_arn, :trajectory_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The job ARN.
50 51 52 53 54 55 56 57 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50 class CompleteRolloutRequest < Struct.new( :job_arn, :trajectory_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The target status for the trajectory. Defaults to READY if not specified. Set to FAILED if the rollout encountered an error and the trajectory should not be used for processing.
50 51 52 53 54 55 56 57 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50 class CompleteRolloutRequest < Struct.new( :job_arn, :trajectory_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |
#trajectory_id ⇒ String
The trajectory ID to mark as complete.
50 51 52 53 54 55 56 57 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 50 class CompleteRolloutRequest < Struct.new( :job_arn, :trajectory_id, :status, :client_token) SENSITIVE = [] include Aws::Structure end |