Class: Aws::SagemakerJobRuntime::Types::UpdateRewardRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SagemakerJobRuntime::Types::UpdateRewardRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerjobruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#job_arn ⇒ String
The job ARN.
-
#rewards ⇒ Array<Float>
The list of reward values to assign to this trajectory.
-
#trajectory_id ⇒ String
The trajectory ID to update with reward values.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
234 235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234 class UpdateRewardRequest < Struct.new( :job_arn, :trajectory_id, :rewards, :client_token) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The job ARN.
234 235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234 class UpdateRewardRequest < Struct.new( :job_arn, :trajectory_id, :rewards, :client_token) SENSITIVE = [] include Aws::Structure end |
#rewards ⇒ Array<Float>
The list of reward values to assign to this trajectory. Provide one reward value per turn in the trajectory.
234 235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234 class UpdateRewardRequest < Struct.new( :job_arn, :trajectory_id, :rewards, :client_token) SENSITIVE = [] include Aws::Structure end |
#trajectory_id ⇒ String
The trajectory ID to update with reward values.
234 235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-sagemakerjobruntime/types.rb', line 234 class UpdateRewardRequest < Struct.new( :job_arn, :trajectory_id, :rewards, :client_token) SENSITIVE = [] include Aws::Structure end |